@@ -30,21 +30,26 @@
 #include "ngtcp2_test_helper.h"
 
 static const MunitTest tests[] = {
-    munit_void_test(test_ngtcp2_pmtud_probe),
-    munit_test_end(),
+  munit_void_test(test_ngtcp2_pmtud_probe),
+  munit_test_end(),
 };
 
 const MunitSuite pmtud_suite = {
-    "/pmtud", tests, NULL, 1, MUNIT_SUITE_OPTION_NONE,
+  "/pmtud", tests, NULL, 1, MUNIT_SUITE_OPTION_NONE,
 };
 
 void test_ngtcp2_pmtud_probe(void) {
   const ngtcp2_mem *mem = ngtcp2_mem_default();
   ngtcp2_pmtud *pmtud;
   int rv;
+  static const uint16_t probes[] = {
+    3000 - 48,
+    9000 - 48,
+  };
 
   /* Send probe and get success */
-  rv = ngtcp2_pmtud_new(&pmtud, NGTCP2_MAX_UDP_PAYLOAD_SIZE, 1452, 0, mem);
+  rv = ngtcp2_pmtud_new(&pmtud, NGTCP2_MAX_UDP_PAYLOAD_SIZE, 1452, 0, NULL, 0,
+                        mem);
 
   assert_int(0, ==, rv);
   assert_size(0, ==, pmtud->mtu_idx);
@@ -103,7 +108,8 @@ void test_ngtcp2_pmtud_probe(void) {
   ngtcp2_pmtud_del(pmtud);
 
   /* Failing 2nd probe should skip the third probe */
-  rv = ngtcp2_pmtud_new(&pmtud, NGTCP2_MAX_UDP_PAYLOAD_SIZE, 1452, 0, mem);
+  rv = ngtcp2_pmtud_new(&pmtud, NGTCP2_MAX_UDP_PAYLOAD_SIZE, 1452, 0, NULL, 0,
+                        mem);
 
   ngtcp2_pmtud_probe_sent(pmtud, 2, 0);
   ngtcp2_pmtud_handle_expiry(pmtud, 2);
@@ -134,7 +140,7 @@ void test_ngtcp2_pmtud_probe(void) {
 
   /* Skip 1st probe because it is larger than hard max. */
   rv = ngtcp2_pmtud_new(&pmtud, NGTCP2_MAX_UDP_PAYLOAD_SIZE, 1454 - 48 - 1, 0,
-                        mem);
+                        NULL, 0, mem);
 
   assert_int(0, ==, rv);
   assert_size(1, ==, pmtud->mtu_idx);
@@ -143,7 +149,7 @@ void test_ngtcp2_pmtud_probe(void) {
 
   /* PMTUD finishes immediately because we know that all candidates
      are lower than the current maximum. */
-  rv = ngtcp2_pmtud_new(&pmtud, 1492 - 48, 1452, 0, mem);
+  rv = ngtcp2_pmtud_new(&pmtud, 1492 - 48, 1452, 0, NULL, 0, mem);
 
   assert_int(0, ==, rv);
   assert_true(ngtcp2_pmtud_finished(pmtud));
@@ -153,10 +159,30 @@ void test_ngtcp2_pmtud_probe(void) {
   /* PMTUD finishes immediately because the hard maximum size is lower
      than the candidates. */
   rv = ngtcp2_pmtud_new(&pmtud, NGTCP2_MAX_UDP_PAYLOAD_SIZE,
-                        NGTCP2_MAX_UDP_PAYLOAD_SIZE, 0, mem);
+                        NGTCP2_MAX_UDP_PAYLOAD_SIZE, 0, NULL, 0, mem);
 
   assert_int(0, ==, rv);
   assert_true(ngtcp2_pmtud_finished(pmtud));
 
   ngtcp2_pmtud_del(pmtud);
+
+  /* Custom probes */
+  rv = ngtcp2_pmtud_new(&pmtud, NGTCP2_MAX_UDP_PAYLOAD_SIZE, 9000 - 48, 0,
+                        probes, ngtcp2_arraylen(probes), mem);
+
+  assert_int(0, ==, rv);
+  assert_size(3000 - 48, ==, ngtcp2_pmtud_probelen(pmtud));
+
+  ngtcp2_pmtud_probe_sent(pmtud, 230, 7);
+  ngtcp2_pmtud_probe_success(pmtud, 3000 - 48);
+
+  assert_false(ngtcp2_pmtud_finished(pmtud));
+  assert_size(9000 - 48, ==, ngtcp2_pmtud_probelen(pmtud));
+
+  ngtcp2_pmtud_probe_sent(pmtud, 230, 9);
+  ngtcp2_pmtud_probe_success(pmtud, 9000 - 48);
+
+  assert_true(ngtcp2_pmtud_finished(pmtud));
+
+  ngtcp2_pmtud_del(pmtud);
 }
